@@ -11,7 +11,7 @@ import icepyx.core.is2ref as is2ref
 class Variables:
     """
     Get, create, interact, and manipulate lists of variables and variable paths
-    contained in ICESat-2 datasets.
+    contained in ICESat-2 products.
 
     Parameters
     ----------
@@ -27,13 +27,13 @@ class Variables:
         A session object authenticating the user to download data using their Earthdata login information.
         The session object will automatically be passed from the query object if you
         have successfully logged in there.
-    dataset : string, default None
-        Properly formatted string specifying a valid ICESat-2 dataset
+    product : string, default None
+        Properly formatted string specifying a valid ICESat-2 product
     version : string, default None
-        Properly formatted string specifying a valid version of the ICESat-2 dataset
-    source : string, default None
-        For vartype file, a path to a directory or single input source files (not yet implemented)
-   """
+        Properly formatted string specifying a valid version of the ICESat-2 product
+    path : string, default None
+        For vartype file, a path to a directory of or single input data file (not yet implemented)
+    """
 
     def __init__(
         self,
@@ -41,15 +41,15 @@ class Variables:
         avail=None,
         wanted=None,
         session=None,
-        dataset=None,
+        product=None,
         version=None,
-        source=None,
+        path=None,
     ):
 
         assert vartype in ["order", "file"], "Please submit a valid variables type flag"
 
         self._vartype = vartype
-        self.dataset = dataset
+        self.product = product
         self._avail = avail
         self.wanted = wanted
         self._session = session
@@ -61,7 +61,7 @@ class Variables:
                 self._version = version
         elif self._vartype == "file":
             # DevGoal: check that the list or string are valid dir/files
-            self.source = source
+            self.path = path
 
     # @property
     # def wanted(self):
@@ -69,7 +69,7 @@ class Variables:
 
     def avail(self, options=False, internal=False):
         """
-        Get the list of available variables and variable paths from the input dataset
+        Get the list of available variables and variable paths from the input data product
 
         Examples
         --------
@@ -77,7 +77,7 @@ class Variables:
         >>> reg_a.earthdata_login(user_id,user_email)
         Earthdata Login password:  ········
         >>> reg_a.order_vars.avail()
-       ['ancillary_data/atlas_sdp_gps_epoch',
+        ['ancillary_data/atlas_sdp_gps_epoch',
         'ancillary_data/control',
         'ancillary_data/data_end_utc',
         'ancillary_data/data_start_utc',
@@ -92,7 +92,7 @@ class Variables:
         if not hasattr(self, "_avail") or self._avail == None:
             if self._vartype == "order":
                 self._avail = is2ref._get_custom_options(
-                    self._session, self.dataset, self._version
+                    self._session, self.product, self._version
                 )["variables"]
 
             elif self._vartype == "file":
@@ -140,39 +140,39 @@ class Variables:
         >>> var_dict.keys()
         dict_keys(['atlas_sdp_gps_epoch', 'control', 'data_end_utc', 'data_start_utc',
         'end_cycle', 'end_delta_time', 'end_geoseg', 'end_gpssow', 'end_gpsweek',
-        'end_orbit', 'end_region', 'end_rgt', 'granule_end_utc', 'granule_start_utc', 
-        'qa_at_interval', 'release', 'start_cycle', 'start_delta_time', 'start_geoseg', 
-        'start_gpssow', 'start_gpsweek', 'start_orbit', 'start_region', 'start_rgt', 
-        'version', 'dt_hist', 'fit_maxiter', 'fpb_maxiter', 'maxiter', 'max_res_ids', 
-        'min_dist', 'min_gain_th', 'min_n_pe', 'min_n_sel', 'min_signal_conf', 'n_hist', 
-        'nhist_bins', 'n_sigmas', 'proc_interval', 'qs_lim_bsc', 'qs_lim_hrs', 'qs_lim_hsigma', 
-        'qs_lim_msw', 'qs_lim_snr', 'qs_lim_sss', 'rbin_width', 'sigma_beam', 'sigma_tx', 
-        't_dead', 'atl06_quality_summary', 'delta_time', 'h_li', 'h_li_sigma', 'latitude', 
-        'longitude', 'segment_id', 'sigma_geo_h', 'fpb_mean_corr', 'fpb_mean_corr_sigma', 
-        'fpb_med_corr', 'fpb_med_corr_sigma', 'fpb_n_corr', 'med_r_fit', 'tx_mean_corr', 
+        'end_orbit', 'end_region', 'end_rgt', 'granule_end_utc', 'granule_start_utc',
+        'qa_at_interval', 'release', 'start_cycle', 'start_delta_time', 'start_geoseg',
+        'start_gpssow', 'start_gpsweek', 'start_orbit', 'start_region', 'start_rgt',
+        'version', 'dt_hist', 'fit_maxiter', 'fpb_maxiter', 'maxiter', 'max_res_ids',
+        'min_dist', 'min_gain_th', 'min_n_pe', 'min_n_sel', 'min_signal_conf', 'n_hist',
+        'nhist_bins', 'n_sigmas', 'proc_interval', 'qs_lim_bsc', 'qs_lim_hrs', 'qs_lim_hsigma',
+        'qs_lim_msw', 'qs_lim_snr', 'qs_lim_sss', 'rbin_width', 'sigma_beam', 'sigma_tx',
+        't_dead', 'atl06_quality_summary', 'delta_time', 'h_li', 'h_li_sigma', 'latitude',
+        'longitude', 'segment_id', 'sigma_geo_h', 'fpb_mean_corr', 'fpb_mean_corr_sigma',
+        'fpb_med_corr', 'fpb_med_corr_sigma', 'fpb_n_corr', 'med_r_fit', 'tx_mean_corr',
         tx_med_corr', 'dem_flag', 'dem_h', 'geoid_h', 'dh_fit_dx', 'dh_fit_dx_sigma', '
-        dh_fit_dy', 'h_expected_rms', 'h_mean', 'h_rms_misfit', 'h_robust_sprd', 
-        'n_fit_photons', 'n_seg_pulses', 'sigma_h_mean', 'signal_selection_source', 
-        'signal_selection_source_status', 'snr', 'snr_significance', 'w_surface_window_final', 
-        ckgrd', 'bsnow_conf', 'bsnow_h', 'bsnow_od', 'cloud_flg_asr', 'cloud_flg_atm', 'dac', 
-        'e_bckgrd', 'layer_flag', 'msw_flag', 'neutat_delay_total', 'r_eff', 'solar_azimuth', 
-        'solar_elevation', 'tide_earth', 'tide_equilibrium', 'tide_load', 'tide_ocean', 
-        'tide_pole', 'ref_azimuth', 'ref_coelv', 'seg_azimuth', 'sigma_geo_at', 'sigma_geo_r', 
-        igma_geo_xt', 'x_atc', 'y_atc', 'bckgrd_per_m', 'bin_top_h', 'count', 'ds_segment_id', 
-        'lat_mean', 'lon_mean', 'pulse_count', 'segment_id_list', 'x_atc_mean', 'record_number', 
-        'reference_pt_lat', 'reference_pt_lon', 'signal_selection_status_all', 
-        'signal_selection_status_backup', 'signal_selection_status_confident', 'crossing_time', 
-        'cycle_number', 'lan', 'orbit_number', 'rgt', 'sc_orient', 'sc_orient_time', 
-        'qa_granule_fail_reason', 'qa_granule_pass_fail', 'signal_selection_source_fraction_0', 
-        'signal_selection_source_fraction_1', 'signal_selection_source_fraction_2', 
+        dh_fit_dy', 'h_expected_rms', 'h_mean', 'h_rms_misfit', 'h_robust_sprd',
+        'n_fit_photons', 'n_seg_pulses', 'sigma_h_mean', 'signal_selection_source',
+        'signal_selection_source_status', 'snr', 'snr_significance', 'w_surface_window_final',
+        ckgrd', 'bsnow_conf', 'bsnow_h', 'bsnow_od', 'cloud_flg_asr', 'cloud_flg_atm', 'dac',
+        'e_bckgrd', 'layer_flag', 'msw_flag', 'neutat_delay_total', 'r_eff', 'solar_azimuth',
+        'solar_elevation', 'tide_earth', 'tide_equilibrium', 'tide_load', 'tide_ocean',
+        'tide_pole', 'ref_azimuth', 'ref_coelv', 'seg_azimuth', 'sigma_geo_at', 'sigma_geo_r',
+        igma_geo_xt', 'x_atc', 'y_atc', 'bckgrd_per_m', 'bin_top_h', 'count', 'ds_segment_id',
+        'lat_mean', 'lon_mean', 'pulse_count', 'segment_id_list', 'x_atc_mean', 'record_number',
+        'reference_pt_lat', 'reference_pt_lon', 'signal_selection_status_all',
+        'signal_selection_status_backup', 'signal_selection_status_confident', 'crossing_time',
+        'cycle_number', 'lan', 'orbit_number', 'rgt', 'sc_orient', 'sc_orient_time',
+        'qa_granule_fail_reason', 'qa_granule_pass_fail', 'signal_selection_source_fraction_0',
+        'signal_selection_source_fraction_1', 'signal_selection_source_fraction_2',
         'signal_selection_source_fraction_3'])
         >>> import numpy
         >>> numpy.unique(paths)
         array(['ancillary_data', 'bias_correction', 'dem', 'fit_statistics',
-       'geophysical', 'ground_track', 'gt1l', 'gt1r', 'gt2l', 'gt2r',
-       'gt3l', 'gt3r', 'land_ice', 'land_ice_segments', 'none',
-       'orbit_info', 'quality_assessment', 'residual_histogram',
-       'segment_quality', 'signal_selection_status'], dtype='<U23')
+        'geophysical', 'ground_track', 'gt1l', 'gt1r', 'gt2l', 'gt2r',
+        'gt3l', 'gt3r', 'land_ice', 'land_ice_segments', 'none',
+        'orbit_info', 'quality_assessment', 'residual_histogram',
+        'segment_quality', 'signal_selection_status'], dtype='<U23')
         """
 
         # create a dictionary of variable names and paths
@@ -205,14 +205,14 @@ class Variables:
         self, vgrp, allpaths, var_list=None, beam_list=None, keyword_list=None
     ):
         """
-        Check that the user is requesting valid paths and/or variables for their dataset.
+        Check that the user is requesting valid paths and/or variables for their product.
 
         See self.append() for further details on the list of input parameters.
 
         Parameters:
         -----------
         vgrp : dict
-            Dictionary containing dataset variables as keys
+            Dictionary containing product variables as keys
 
         allpaths : list
             List of all potential path keywords
@@ -227,7 +227,7 @@ class Variables:
             List of user requested variable path keywords
 
         """
-        # check if the list of variables, if specified, are available in the dataset
+        # check if the list of variables, if specified, are available in the product
         if var_list is not None:
             for var_id in var_list:
                 if var_id not in vgrp.keys():
@@ -237,8 +237,8 @@ class Variables:
                     raise ValueError(err_msg_varid)
 
         # DevGoal: is there a way to not have this hard-coded in?
-        # check if the list of beams, if specified, are available in the dataset
-        if self.dataset == "ATL09":
+        # check if the list of beams, if specified, are available in the product
+        if self.product == "ATL09":
             beam_avail = ["profile_" + str(i + 1) for i in range(3)]
         else:
             beam_avail = ["gt" + str(i + 1) + "l" for i in range(3)]
@@ -251,7 +251,7 @@ class Variables:
                     err_msg_beam = err_msg_beam + ", ".join(beam_avail)
                     raise ValueError(err_msg_beam)
 
-        # check if keywords, if specified, are available for the dataset
+        # check if keywords, if specified, are available for the product
         if keyword_list is not None:
             for kw in keyword_list:
                 #                 assert kw in allpaths, "Invalid keyword. Please select from: " + ', '.join(allpaths)
@@ -269,7 +269,7 @@ class Variables:
         """
         sum_varlist = []
         if defaults == True:
-            sum_varlist = sum_varlist + is2ref._default_varlists(self.dataset)
+            sum_varlist = sum_varlist + is2ref._default_varlists(self.product)
         if var_list is not None:
             for vn in var_list:
                 if vn not in sum_varlist:
@@ -336,37 +336,37 @@ class Variables:
     # DevGoal: we can ultimately add an "interactive" trigger that will open the not-yet-made widget. Otherwise, it will use the var_list passed by the user/defaults
     def append(self, defaults=False, var_list=None, beam_list=None, keyword_list=None):
         """
-        Add to the list of desired variables using user specified beams and variable list. 
-        A pregenerated default variable list can be used by setting defaults to True. 
+        Add to the list of desired variables using user specified beams and variable list.
+        A pregenerated default variable list can be used by setting defaults to True.
         Note: The calibrated backscatter cab_prof is not in the default list for ATL09
-        
+
         Parameters
         ----------
         defaults : boolean, default False
-            Include the variables in the default variable list. Defaults are defined per-data product. 
+            Include the variables in the default variable list. Defaults are defined per-data product.
             When specified in conjuction with a var_list, default variables not on the user-
             specified list will be added to the order.
 
         var_list : list of strings, default None
-            A list of variables to request, if not all available variables are wanted. 
+            A list of variables to request, if not all available variables are wanted.
             A list of available variables can be obtained by entering `var_list=['']` into the function.
 
         beam_list : list of strings, default None
-            A list of beam strings, if only selected beams are wanted (the default value of None will automatically 
+            A list of beam strings, if only selected beams are wanted (the default value of None will automatically
             include all beams). For ATL09, acceptable values are ['profile_1', 'profile_2', 'profile_3'].
-            For all other datasets, acceptable values are ['gt1l', 'gt1r', 'gt2l', 'gt2r', 'gt3l', 'gt3r'].
+            For all other products, acceptable values are ['gt1l', 'gt1r', 'gt2l', 'gt2r', 'gt3l', 'gt3r'].
 
         keyword_list : list of strings, default None
             A list of subdirectory names (keywords), from any heirarchy level within the data structure, to select variables within
-            the dataset that include that keyword in their path. A list of availble keywords can be obtained by
+            the product that include that keyword in their path. A list of availble keywords can be obtained by
             entering `keyword_list=['']` into the function.
 
         Notes
         -----
-        See also the `ICESat-2_DAAC_DataAccess2_Subsetting 
-        <https://github.com/icesat2py/icepyx/blob/master/doc/examples/ICESat-2_DAAC_DataAccess2_Subsetting.ipynb>`_
+        See also the `ICESat-2_DAAC_DataAccess2_Subsetting
+        <https://github.com/icesat2py/icepyx/blob/main/doc/examples/ICESat-2_DAAC_DataAccess2_Subsetting.ipynb>`_
         example notebook
-        
+
         Examples
         --------
         >>> reg_a = icepyx.query.Query('ATL06',[-55, 68, -48, 71],['2019-02-20','2019-02-28'])
@@ -374,19 +374,19 @@ class Variables:
         Earthdata Login password:  ········
 
         To add all variables related to a specific ICESat-2 beam
-        
+
         >>> reg_a.order_vars.append(beam_list=['gt1r'])
-        
+
         To include the default variables:
-        
+
         >>> reg_a.order_vars.append(defaults=True)
 
         To add specific variables in orbit_info
-        
+
         >>> reg_a.order_vars.append(keyword_list=['orbit_info'],var_list=['sc_orient_time'])
 
         To add all variables and paths in ancillary_data
-        
+
         >>> reg_a.order_vars.append(keyword_list=['ancillary_data'])
         """
 
@@ -454,32 +454,32 @@ class Variables:
     def remove(self, all=False, var_list=None, beam_list=None, keyword_list=None):
         """
         Remove the variables and paths from the wanted list using user specified beam, keyword,
-         and variable lists. 
-        
+         and variable lists.
+
         Parameters:
         -----------
         all : boolean, default False
             Remove all variables and paths from the wanted list.
-        
+
         var_list : list of strings, default None
-            A list of variables to request, if not all available variables are wanted. 
+            A list of variables to request, if not all available variables are wanted.
             A list of available variables can be obtained by entering `var_list=['']` into the function.
 
         beam_list : list of strings, default None
-            A list of beam strings, if only selected beams are wanted (the default value of None will automatically 
+            A list of beam strings, if only selected beams are wanted (the default value of None will automatically
             include all beams). For ATL09, acceptable values are ['profile_1', 'profile_2', 'profile_3'].
-            For all other datasets, acceptable values are ['gt1l', 'gt1r', 'gt2l', 'gt2r', 'gt3l', 'gt3r'].
+            For all other products, acceptable values are ['gt1l', 'gt1r', 'gt2l', 'gt2r', 'gt3l', 'gt3r'].
 
         keyword_list : list of strings, default None
             A list of subdirectory names (keywords), from any heirarchy level within the data structure, to select variables within
-            the dataset that include that keyword in their path.
+            the product that include that keyword in their path.
 
         Notes
         -----
-        See also the `ICESat-2_DAAC_DataAccess2_Subsetting 
-        <https://github.com/icesat2py/icepyx/blob/master/doc/examples/ICESat-2_DAAC_DataAccess2_Subsetting.ipynb>`_
+        See also the `ICESat-2_DAAC_DataAccess2_Subsetting
+        <https://github.com/icesat2py/icepyx/blob/main/doc/examples/ICESat-2_DAAC_DataAccess2_Subsetting.ipynb>`_
         example notebook
-        
+
         Examples
         --------
         >>> reg_a = icepyx.query.Query('ATL06',[-55, 68, -48, 71],['2019-02-20','2019-02-28'])
@@ -487,19 +487,19 @@ class Variables:
         Earthdata Login password:  ········
 
         To clear the list of wanted variables
-        
+
         >>> reg_a.order_vars.remove(all=True)
-        
+
         To remove all variables related to a specific ICESat-2 beam
-        
+
         >>> reg_a.order_vars.remove(beam_list=['gt1r'])
 
         To remove specific variables in orbit_info
-        
+
         >>> reg_a.order_vars.remove(keyword_list=['orbit_info'],var_list=['sc_orient_time'])
 
         To remove all variables and paths in ancillary_data
-        
+
         >>> reg_a.order_vars.remove(keyword_list=['ancillary_data'])
         """
 
